import json
import uuid

import h2o_mlops_client as mlops

# Defines MLOps API URL. The address for the MLOps Gateway component.
# Usually: "https://api.mlops.my.domain"
MLOPS_API_URL = ""

# Defines IDP's token endpoint URL. For deployments using Keycloak as IDP:
# https://mlops.keycloak.domain/auth/realms/[fill-in-realm-name]/protocol/openid-connect/token
TOKEN_ENDPOINT_URL = ""

# Defines user's refresh token.
REFRESH_TOKEN = ""

# Sets client id for authentication.
CLIENT_ID = ""

# Sets client secret for authentication.
CLIENT_SECRET = ""

# Set registered model version id. 
REGISTERED_MODEL_VERSION_ID = ""


# Get model version for the given model version id.
def get_model_version(mlops_client: mlops.Client, get_model_version_request: mlops.StorageGetModelVersionRequest):
    return mlops_client.storage.registered_model_version.get_model_version(get_model_version_request)


def get_model_version_request(model_version_id):
    return mlops.StorageGetModelVersionRequest(model_version_id=model_version_id)


def main():
    # Set up the token provider using an existing refresh token.
    mlops_token_provider = mlops.TokenProvider(
        refresh_token=REFRESH_TOKEN,
        client_id=CLIENT_ID,
        client_secret=CLIENT_SECRET,
        token_endpoint_url=TOKEN_ENDPOINT_URL,
    )

    # Set up the MLOps client.
    mlops_client = mlops.Client(
        gateway_url=MLOPS_API_URL,
        token_provider=mlops_token_provider,
    )

    # Get registered model for the given registered model version.
    get_model_version_response: mlops.StorageGetRegisteredModelResponse = get_model_version(
        mlops_client=mlops_client,
            get_model_version_request=get_model_version_request(
                model_version_id=REGISTERED_MODEL_VERSION_ID
            )
        )
    print(get_model_version_response)


if __name__ == "__main__":
    main()